Crate co_api

Crate co_api 

Modules

serde_map_as_list

Macros

tags
Tags inline macro.

Structs

AbsolutePath
Absolute Path.
AbsolutePathOwned
Owned Absolute Path.
Block
Block
BlockSerializer
DagCbor Block Serializer/Deserializer.
Clock
Lamport Clock.
CoId
CO Unique ID.
CoList
CoList stored values in a sequence.
CoListIndex
CoList index - non continous.
CoListTransaction
CoMap
CoMapTransaction
CoSet
CoSetTransaction
Components
Path components.
CoreBlockStorage
DefaultNodeSerializer
DefaultParams
Entry
GuardInput
GuardOutput
GuardRef
LazyTransaction
Lazy transaction that only opens the transaction when used.
Link
A (serializable) typed link.
NodeBuilder
Create a balances merkle tree of Node blocks.
OptionLink
A (serializable) typed link.
Path
Path. Can be relative or absolute.
PathOwned
Owned Path.
ReducerAction
ReducerInput
ReducerOutput
ReducerRef
RelativePath
Relative Path.
RelativePathOwned
OWned Relative Path.
Secret
Simple wrapper type for secrents to not escape them.
SignedEntry
Tags
Tags.
TotalFloat64
f64 float wich uses total order from IEEE 754 (2008 revision).
WeakCid
A CID that will be serialized as just bytes and will not be returned by crate::BlockLinks.
WithCoMetadata

Enums

BlockSerializerError
CoReference
Wrapps a reference/link/Cid and applies attributes useful in context of a Co.
Component
Path component.
Metadata
Network
Network service connectivity description.
Node
NodeBuilderError
StorageError
TagValue
Tag Value
TagsExpr
Tags match pattern.

Constants

CID_MAX_SIZE

Traits

BlockStorage
BlockStorageExt
CoMetadata
Special CO metadata.
CoTryStreamExt
Context
COre execution context.
Guard
IsDefault
Simple trait to check if the current value is the default.
Linkable
NodeSerializer
PathExt
Reducer
Storage
Storage interface.
StoreParams
TagMatcher
A type that can be matched against a tag.
TagPattern
A type that can be used as pattern to be matched against a TagMatcher.

Functions

cid_to_raw
from_cbor
Deserialize from CBOR (using dag-json).
from_json
Deserialize from JSON string (using dag-json).
guard
raw_to_cid
reduce
reducer_action_core
Read core property from a ReducerAction.
reducer_action_core_from_storage
Read core property from a ReducerAction.
storage_block_get
Stub
storage_block_set
Stub
to_cbor
Serialize value to CBOR string (using dag-json).
to_json
Serialize value to JSON string (using dag-json).
to_json_string
Serialize value to JSON string (using dag-json).

Type Aliases

Cid
exports A Cid that contains a multihash with an allocated size of 512 bits.
Date
Did
RawCid
Tag
Tag. Represents a generic metadata/configuration key value pair.

Attribute Macros

co